16.1. cdist-type__acl(7) — cdist 6.1.1 documentation

# 16.1. cdist-type__acl(7)

## 16.1.1. NAME

cdist-type__acl - Set ACL entries

## 16.1.2. DESCRIPTION

Fully supported and tested on Linux (ext4 filesystem), partial support for FreeBSD.

See `setfacl` and `acl` manpages for more details.

## 16.1.3. REQUIRED MULTIPLE PARAMETERS

acl
  Set ACL entry following `getfacl` output syntax.

## 16.1.4. BOOLEAN PARAMETERS

default
  Set all ACL entries as default too. Only directories can have default ACLs. Setting default ACL in FreeBSD is currently not supported.
recursive
  Make `setfacl` recursive (Linux only), but not `getfacl` in explorer.
remove
  Remove undefined ACL entries. `mask` and `other` entries can't be removed, but only changed.

## 16.1.5. DEPRECATED PARAMETERS

Parameters `user`, `group`, `mask` and `other` are deprecated and they will be removed in future versions. Please use `acl` parameter instead.

## 16.1.6. EXAMPLES

    __acl /srv/project \
        --default \
        --recursive \
        --remove \
        --acl user:alice:rwx \
        --acl user:bob:r-x \
        --acl group:project-group:rwx \
        --acl group:some-other-group:r-x \
        --acl mask::r-x \
        --acl other::r-x

    # give Alice read-only access to subdir,
    # but don't allow her to see parent content.

    __acl /srv/project2 \
        --remove \
        --acl default:group:secret-project:rwx \
        --acl group:secret-project:rwx \
        --acl user:alice:--x

    __acl /srv/project2/subdir \
        --default \
        --remove \
        --acl group:secret-project:rwx \
        --acl user:alice:r-x

## 16.1.7. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.1.8. COPYING

Copyright (C) 2018 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.